package org.test;

import org.kie.api.KieServices;
import org.kie.api.builder.KieScanner;
import org.kie.api.builder.ReleaseId;
import org.kie.api.runtime.KieContainer;
import org.kie.api.runtime.KieSession;

/**
 * Tests creating a KieSession from a KieModule stored in external Maven repo (configured in Maven settings.xml)
 * accessed via KIE-CI.
 */
public class KieCISessionUpdate {

    private static final ReleaseId EXTERNAL_KJAR = getServices()
            .newReleaseId("org.jboss.qa.brms", "mw-child", "LATEST");

    private static KieServices getServices() {
        return KieServices.Factory.get();
    }

    public static void main(final String... args) throws InterruptedException {
        final KieServices ks = getServices();
        final KieContainer kcontainer = ks.newKieContainer(EXTERNAL_KJAR);
        final KieScanner kscanner = ks.newKieScanner(kcontainer);
        kscanner.start(1000L);
        final KieSession ksession = kcontainer.newKieSession("childKSession");

        int iteration = 0;
        try {
            while (true) {
                String fact = String.format("Iteration: %d", iteration);
                ksession.insert(fact);
                ksession.fireAllRules();
                Thread.sleep(5000);
            }
        } finally {
            kscanner.shutdown();
            ksession.dispose();
        }
    }
}
